@@ -7,11 +7,12 @@
 # nor does it submit to any jurisdiction.
 #
 
-import ecmwfapi
-import os
 import json
+import os
 
-from .base import FileSource, APIKeyPrompt
+import ecmwfapi
+
+from .base import APIKeyPrompt, FileSource
 
 
 class MARSAPI(APIKeyPrompt):
@@ -68,8 +69,8 @@ def service(name):
         if ".ecmwfapirc" in str(e):
             MARSAPI().ask_user_and_save()
             return ecmwfapi.ECMWFService(name)
-        else:
-            raise
+
+        raise
 
 
 class MARSRetriever(FileSource):
